@@ -57,9 +57,15 @@ import pandas as pd
               type=float,
               default=0.05,
               help='Count filter threshold')
+@click.option("--min_counts", '-mc',
+              metavar='<int>',
+              type=int,
+              default=5,
+              help='Minimum read counts for barcode to be inclucded')
 def run(input_dir, exp_design, cores,map_quality,seq_quality,gb_ref, bowtie_ref, 
                                 tn_seq, tn_mismatch, 
-                                use_barcodes, bar_upstream, bar_downstream, filter_thr):
+                                use_barcodes, bar_upstream, bar_downstream, filter_thr,
+                                min_counts):
     """ 
     Run pysudoku to process sequencing data from combnatorially pooled 
     arrayed libraries and infer the most likely locations for each mutant.
@@ -135,9 +141,15 @@ def run(input_dir, exp_design, cores,map_quality,seq_quality,gb_ref, bowtie_ref,
               type=float,
               default=0.05,
               help='Count filter threshold')
+@click.option("--min_counts", '-mc',
+              metavar='<int>',
+              type=int,
+              default=20,
+              help='Minimum read counts for barcode to be inclucded')
 def run_on_barcodes(input_dir, exp_design, cores,map_quality,seq_quality, 
                                 tn_seq, tn_mismatch, 
-                                 bar_upstream, bar_downstream, filter_thr):
+                                 bar_upstream, bar_downstream, filter_thr,
+                                 min_counts):
     """ 
     Run pysudoku in barcode only mode, where no alignment to the reference 
     genome is performed.
